@@ -8,6 +8,7 @@
 namespace Zend\Hydrator;
 
 use Interop\Container\ContainerInterface;
+use Zend\ServiceManager\Config;
 use Zend\ServiceManager\FactoryInterface;
 use Zend\ServiceManager\ServiceLocatorInterface;
 
@@ -27,7 +28,30 @@ class HydratorPluginManagerFactory implements FactoryInterface
      */
     public function __invoke(ContainerInterface $container, $name, array $options = null)
     {
-        return new HydratorPluginManager($container, $options ?: []);
+        $pluginManager = new HydratorPluginManager($container, $options ?: []);
+
+        // If this is in a zend-mvc application, the ServiceListener will inject
+        // merged configuration during bootstrap.
+        if ($container->has('ServiceListener')) {
+            return $pluginManager;
+        }
+
+        // If we do not have a config service, nothing more to do
+        if (! $container->has('config')) {
+            return $pluginManager;
+        }
+
+        $config = $container->get('config');
+
+        // If we do not have hydrators configuration, nothing more to do
+        if (! isset($config['hydrators']) || ! is_array($config['hydrators'])) {
+            return $pluginManager;
+        }
+
+        // Wire service configuration for hydrators
+        (new Config($config['hydrators']))->configureServiceManager($pluginManager);
+
+        return $pluginManager;
     }
 
     /**
